@@ -280,7 +280,7 @@ class LStar:
         # First we make sure that normalization is not the source of the
         # failure to match.
         while True:
-            normalized = bytes([self.normalizer.normalize(c) for c in string])
+            normalized = bytes(self.normalizer.normalize(c) for c in string)
             # We can correctly replace the string with its normalized version
             # so normalization is not the problem here.
             if self.member(normalized) == correct_outcome:
@@ -293,7 +293,7 @@ class LStar:
                 def replace(b):
                     if a == b:
                         return target
-                    return bytes([b if c == a else c for c in target])
+                    return bytes(b if c == a else c for c in target)
 
                 self.normalizer.distinguish(a, lambda x: self.member(replace(x)))
                 target = replace(self.normalizer.normalize(a))
@@ -389,7 +389,7 @@ class LearnedDFA(DFA):
     distinguished by a membership test and a set of experiments."""
 
     def __init__(self, lstar):
-        DFA.__init__(self)
+        super().__init__()
         self.__lstar = lstar
         self.__generation = lstar.generation
 
@@ -447,7 +447,7 @@ class IntegerNormalizer:
         self.__cache = {}
 
     def __repr__(self):
-        return "IntegerNormalizer(%r)" % (list(self.__values),)
+        return f"IntegerNormalizer({list(self.__values)!r})"
 
     def __copy__(self):
         result = IntegerNormalizer()
